pub struct AdClients {
pub etag: Option<String>,
pub items: Option<Vec<AdClient>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- adclients list accounts (response)
- list adclients (response)
Fields
etag: Option<String>ETag of this response for caching purposes.
items: Option<Vec<AdClient>>The ad clients returned in this list response.
kind: Option<String>Kind of list this is, in this case adsensehost#adClients.
next_page_token: Option<String>Continuation token used to page through ad clients. To retrieve the next page of results, set the next request’s “pageToken” value to this.