pub struct AdStyle {
pub colors: Option<AdStyleColors>,
pub corners: Option<String>,
pub font: Option<AdStyleFont>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
colors: Option<AdStyleColors>The colors included in the style. These are represented as six hexadecimal characters, similar to HTML color codes, but without the leading hash.
corners: Option<String>The style of the corners in the ad (deprecated: never populated, ignored).
font: Option<AdStyleFont>The font which is included in the style.
kind: Option<String>Kind this is, in this case adsensehost#adStyle.