AdStyleColors

Struct AdStyleColors 

pub struct AdStyleColors {
    pub background: Option<String>,
    pub border: Option<String>,
    pub text: Option<String>,
    pub title: Option<String>,
    pub url: Option<String>,
}
The colors included in the style. These are represented as six hexadecimal characters, similar to HTML color codes, but without the leading hash.

This type is not used in any activity, and only used as part of another schema.

Fields

background: Option<String>

The color of the ad background.

border: Option<String>

The color of the ad border.

text: Option<String>

The color of the ad text.

title: Option<String>

The color of the ad title.

url: Option<String>

The color of the ad url.