pub struct AdUnitContentAdsSettings {
pub backup_option: Option<AdUnitContentAdsSettingsBackupOption>,
pub size: Option<String>,
pub type_: Option<String>,
}Expand description
Settings specific to content ads (AFC) and highend mobile content ads (AFMC - deprecated).
This type is not used in any activity, and only used as part of another schema.
Fields
backup_option: Option<AdUnitContentAdsSettingsBackupOption>The backup option to be used in instances where no ad is available.
size: Option<String>Size of this ad unit. Size values are in the form SIZE_{width}_{height}.
type_: Option<String>Type of this ad unit. Possible values are TEXT, TEXT_IMAGE, IMAGE and LINK.