pub struct AdclientMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on adclient resources.
It is not used directly, but through the AdSenseHost hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_adsensehost4d1 as adsensehost4d1;
use adsensehost4d1::{AdSenseHost, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AdSenseHost::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)` and `list(...)`
// to build up your call.
let rb = hub.adclients();Implementations
Sourceimpl<'a, C> AdclientMethods<'a, C>
impl<'a, C> AdclientMethods<'a, C>
Sourcepub fn get(&self, ad_client_id: &str) -> AdclientGetCall<'a, C>
pub fn get(&self, ad_client_id: &str) -> AdclientGetCall<'a, C>
Create a builder to help you perform the following task:
Get information about one of the ad clients in the Host AdSense account.
Arguments
adClientId- Ad client to get.
Sourcepub fn list(&self) -> AdclientListCall<'a, C>
pub fn list(&self) -> AdclientListCall<'a, C>
Create a builder to help you perform the following task:
List all host ad clients in this AdSense account.