AssociationSession

Struct AssociationSession 

pub struct AssociationSession {
    pub account_id: Option<String>,
    pub id: Option<String>,
    pub kind: Option<String>,
    pub product_codes: Option<Vec<String>>,
    pub redirect_url: Option<String>,
    pub status: Option<String>,
    pub user_locale: Option<String>,
    pub website_locale: Option<String>,
    pub website_url: Option<String>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

account_id: Option<String>

Hosted account id of the associated publisher after association. Present if status is ACCEPTED.

id: Option<String>

Unique identifier of this association session.

kind: Option<String>

Kind of resource this is, in this case adsensehost#associationSession.

product_codes: Option<Vec<String>>

The products to associate with the user. Options: AFC, AFG, AFV, AFS (deprecated), AFMC (deprecated)

redirect_url: Option<String>

Redirect URL of this association session. Used to redirect users into the AdSense association flow.

status: Option<String>

Status of the completed association, available once the association callback token has been verified. One of ACCEPTED, REJECTED, or ERROR.

user_locale: Option<String>

The preferred locale of the user themselves when going through the AdSense association flow.

website_locale: Option<String>

The locale of the user’s hosted website.

website_url: Option<String>

The URL of the user’s hosted website.