pub struct CustomchannelMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on customchannel resources.
It is not used directly, but through the AdSenseHost hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_adsensehost4d1 as adsensehost4d1;
use adsensehost4d1::{AdSenseHost, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AdSenseHost::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.customchannels();Implementations
Sourceimpl<'a, C> CustomchannelMethods<'a, C>
impl<'a, C> CustomchannelMethods<'a, C>
Sourcepub fn delete(
&self,
ad_client_id: &str,
custom_channel_id: &str,
) -> CustomchannelDeleteCall<'a, C>
pub fn delete( &self, ad_client_id: &str, custom_channel_id: &str, ) -> CustomchannelDeleteCall<'a, C>
Create a builder to help you perform the following task:
Delete a specific custom channel from the host AdSense account.
Arguments
adClientId- Ad client from which to delete the custom channel.customChannelId- Custom channel to delete.
Sourcepub fn get(
&self,
ad_client_id: &str,
custom_channel_id: &str,
) -> CustomchannelGetCall<'a, C>
pub fn get( &self, ad_client_id: &str, custom_channel_id: &str, ) -> CustomchannelGetCall<'a, C>
Create a builder to help you perform the following task:
Get a specific custom channel from the host AdSense account.
Arguments
adClientId- Ad client from which to get the custom channel.customChannelId- Custom channel to get.
Sourcepub fn insert(
&self,
request: CustomChannel,
ad_client_id: &str,
) -> CustomchannelInsertCall<'a, C>
pub fn insert( &self, request: CustomChannel, ad_client_id: &str, ) -> CustomchannelInsertCall<'a, C>
Create a builder to help you perform the following task:
Add a new custom channel to the host AdSense account.
Arguments
request- No description provided.adClientId- Ad client to which the new custom channel will be added.
Sourcepub fn list(&self, ad_client_id: &str) -> CustomchannelListCall<'a, C>
pub fn list(&self, ad_client_id: &str) -> CustomchannelListCall<'a, C>
Create a builder to help you perform the following task:
List all host custom channels in this AdSense account.
Arguments
adClientId- Ad client for which to list custom channels.
Sourcepub fn patch(
&self,
request: CustomChannel,
ad_client_id: &str,
custom_channel_id: &str,
) -> CustomchannelPatchCall<'a, C>
pub fn patch( &self, request: CustomChannel, ad_client_id: &str, custom_channel_id: &str, ) -> CustomchannelPatchCall<'a, C>
Create a builder to help you perform the following task:
Update a custom channel in the host AdSense account. This method supports patch semantics.
Arguments
request- No description provided.adClientId- Ad client in which the custom channel will be updated.customChannelId- Custom channel to get.
Sourcepub fn update(
&self,
request: CustomChannel,
ad_client_id: &str,
) -> CustomchannelUpdateCall<'a, C>
pub fn update( &self, request: CustomChannel, ad_client_id: &str, ) -> CustomchannelUpdateCall<'a, C>
Create a builder to help you perform the following task:
Update a custom channel in the host AdSense account.
Arguments
request- No description provided.adClientId- Ad client in which the custom channel will be updated.