[][src]Struct google_adsensehost4d1::AdCode

pub struct AdCode {
    pub ad_code: Option<String>,
    pub kind: Option<String>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

ad_code: Option<String>

The ad code snippet.

kind: Option<String>

Kind this is, in this case adsensehost#adCode.